pub struct PostBundleFeedbackCache { /* private fields */ }Expand description
Intermediate-server cache for EncodedPostBundleFeedbackV1 data.
Two Moka caches:
bundles: weightedCache<Id, Arc<Mutex<CachedPostBundleFeedbackLocationEntry>>>with TTI. If a location_id hasn’t been queried withinCACHE_LOCATION_TTI, the entry is evicted.inflight:Cache<Id, ()>with 30-second TTL — tracks pending upload tokens.
Implementations
Sourceimpl PostBundleFeedbackCache
impl PostBundleFeedbackCache
pub fn new(max_bytes: u64) -> Self
Sourcepub fn on_get(
&self,
bucket_location: &BucketLocation,
already_retrieved_peer_ids: &[Id],
peer_self: &Peer,
server_id: &ServerId,
now: TimeMillis,
) -> GetCacheResult
pub fn on_get( &self, bucket_location: &BucketLocation, already_retrieved_peer_ids: &[Id], peer_self: &Peer, server_id: &ServerId, now: TimeMillis, ) -> GetCacheResult
Called by the dispatch handler when serving a GetPostBundleFeedbackV1 request.
Sourcepub fn on_upload(
&self,
location_id: Id,
originator_peer_id: Id,
feedback_bytes: Bytes,
server_time: TimeMillis,
is_sealed: bool,
) -> bool
pub fn on_upload( &self, location_id: Id, originator_peer_id: Id, feedback_bytes: Bytes, server_time: TimeMillis, is_sealed: bool, ) -> bool
Called by the dispatch handler when a CachePostBundleFeedbackV1 upload arrives.
Unconditionally replaces any previously cached feedback — the uploader has the merged best.
Returns true if accepted, false if the entry was evicted before the upload arrived.